# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpas-india/FlightLog.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpas-india/FlightLog.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x1arpas-india/FlightLog.proto\"7\n\x03Log\x12\x1d\n\tflightLog\x18\x01 \x01(\x0b\x32\n.FlightLog\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"\xd8\x02\n\tFlightLog\x12\x1a\n\x12permissionArtefact\x18\x01 \x01(\t\x12\'\n\nlogEntries\x18\x02 \x03(\x0b\x32\x13.FlightLog.LogEntry\x12\x17\n\x0fpreviousLogHash\x18\x03 \x01(\x0c\x1a\x8a\x01\n\x08LogEntry\x12\'\n\tentryType\x18\x01 \x01(\x0e\x32\x14.FlightLog.EntryType\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x11\n\tlongitude\x18\x03 \x01(\x01\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x10\n\x08\x61ltitude\x18\x05 \x01(\x01\x12\x0b\n\x03\x63rc\x18\x06 \x01(\x0c\"`\n\tEntryType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bTAKEOFF_ARM\x10\x01\x12\x13\n\x0fGEOFENCE_BREACH\x10\x02\x12\x0f\n\x0bTIME_BREACH\x10\x03\x12\x0f\n\x0bLAND_DISARM\x10\x04\x62\x06proto3'
)



_FLIGHTLOG_ENTRYTYPE = _descriptor.EnumDescriptor(
  name='EntryType',
  full_name='FlightLog.EntryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAKEOFF_ARM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEOFENCE_BREACH', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_BREACH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LAND_DISARM', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=336,
  serialized_end=432,
)
_sym_db.RegisterEnumDescriptor(_FLIGHTLOG_ENTRYTYPE)


_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flightLog', full_name='Log.flightLog', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='Log.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30,
  serialized_end=85,
)


_FLIGHTLOG_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='FlightLog.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entryType', full_name='FlightLog.LogEntry.entryType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FlightLog.LogEntry.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='FlightLog.LogEntry.longitude', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='FlightLog.LogEntry.latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='altitude', full_name='FlightLog.LogEntry.altitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='crc', full_name='FlightLog.LogEntry.crc', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=334,
)

_FLIGHTLOG = _descriptor.Descriptor(
  name='FlightLog',
  full_name='FlightLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissionArtefact', full_name='FlightLog.permissionArtefact', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logEntries', full_name='FlightLog.logEntries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previousLogHash', full_name='FlightLog.previousLogHash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FLIGHTLOG_LOGENTRY, ],
  enum_types=[
    _FLIGHTLOG_ENTRYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=432,
)

_LOG.fields_by_name['flightLog'].message_type = _FLIGHTLOG
_FLIGHTLOG_LOGENTRY.fields_by_name['entryType'].enum_type = _FLIGHTLOG_ENTRYTYPE
_FLIGHTLOG_LOGENTRY.containing_type = _FLIGHTLOG
_FLIGHTLOG.fields_by_name['logEntries'].message_type = _FLIGHTLOG_LOGENTRY
_FLIGHTLOG_ENTRYTYPE.containing_type = _FLIGHTLOG
DESCRIPTOR.message_types_by_name['Log'] = _LOG
DESCRIPTOR.message_types_by_name['FlightLog'] = _FLIGHTLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Log = _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
  'DESCRIPTOR' : _LOG,
  '__module__' : 'rpas_india.FlightLog_pb2'
  # @@protoc_insertion_point(class_scope:Log)
  })
_sym_db.RegisterMessage(Log)

FlightLog = _reflection.GeneratedProtocolMessageType('FlightLog', (_message.Message,), {

  'LogEntry' : _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTLOG_LOGENTRY,
    '__module__' : 'rpas_india.FlightLog_pb2'
    # @@protoc_insertion_point(class_scope:FlightLog.LogEntry)
    })
  ,
  'DESCRIPTOR' : _FLIGHTLOG,
  '__module__' : 'rpas_india.FlightLog_pb2'
  # @@protoc_insertion_point(class_scope:FlightLog)
  })
_sym_db.RegisterMessage(FlightLog)
_sym_db.RegisterMessage(FlightLog.LogEntry)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpas-india/PermissionArtefact.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpas-india/PermissionArtefact.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n#rpas-india/PermissionArtefact.proto\"\xd1\x01\n\x0cUAPermission\x12\x13\n\x0blastUpdated\x18\x01 \x01(\x04\x12\x0b\n\x03ttl\x18\x02 \x01(\x02\x12\r\n\x05txnId\x18\x03 \x01(\t\x12\x1c\n\x14permissionartefactId\x18\x04 \x01(\t\x12\x14\n\x0cpilotPinHash\x18\x05 \x01(\t\x12\x1b\n\x08operator\x18\x06 \x01(\x0b\x32\t.Operator\x12%\n\rflightDetails\x18\x07 \x01(\x0b\x32\x0e.FlightDetails\x12\x18\n\x10\x64igitalSignature\x18\x08 \x01(\x0c\"d\n\x08Operator\x12\x12\n\noperatorID\x18\x01 \x01(\t\x12\x1e\n\x05pilot\x18\x02 \x01(\x0b\x32\x0f.Operator.Pilot\x1a$\n\x05Pilot\x12\n\n\x02no\x18\x01 \x01(\t\x12\x0f\n\x07validTo\x18\x02 \x01(\x04\"\xb8\x04\n\rFlightDetails\x12+\n\tuaDetails\x18\x01 \x01(\x0b\x32\x18.FlightDetails.UADetails\x12\x33\n\rflightPurpose\x18\x02 \x01(\x0b\x32\x1c.FlightDetails.FlightPurpose\x12\x35\n\x0epayloadDetails\x18\x03 \x01(\x0b\x32\x1d.FlightDetails.PayloadDetails\x12\x39\n\x10\x66lightParameters\x18\x04 \x01(\x0b\x32\x1f.FlightDetails.FlightParameters\x1a\x1a\n\tUADetails\x12\r\n\x05uinNo\x18\x01 \x01(\t\x1a\x35\n\rFlightPurpose\x12\x11\n\tshortDesc\x18\x01 \x01(\t\x12\x11\n\tfrequency\x18\x02 \x01(\r\x1a?\n\x0ePayloadDetails\x12\x15\n\rpayLoadWeight\x18\x01 \x01(\x01\x12\x16\n\x0epayloadDetails\x18\x02 \x01(\t\x1a\x31\n\nCoordinate\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x1a\x8b\x01\n\x10\x46lightParameters\x12.\n\x0b\x63oordinates\x18\x01 \x03(\x0b\x32\x19.FlightDetails.Coordinate\x12\x17\n\x0f\x66lightStartTime\x18\x02 \x01(\x04\x12\x15\n\rflightEndTime\x18\x03 \x01(\x04\x12\x17\n\x0f\x66requenciesUsed\x18\x04 \x01(\x02\x62\x06proto3'
)




_UAPERMISSION = _descriptor.Descriptor(
  name='UAPermission',
  full_name='UAPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='UAPermission.lastUpdated', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='UAPermission.ttl', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txnId', full_name='UAPermission.txnId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='permissionartefactId', full_name='UAPermission.permissionartefactId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pilotPinHash', full_name='UAPermission.pilotPinHash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='UAPermission.operator', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightDetails', full_name='UAPermission.flightDetails', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digitalSignature', full_name='UAPermission.digitalSignature', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=249,
)


_OPERATOR_PILOT = _descriptor.Descriptor(
  name='Pilot',
  full_name='Operator.Pilot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='no', full_name='Operator.Pilot.no', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validTo', full_name='Operator.Pilot.validTo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=351,
)

_OPERATOR = _descriptor.Descriptor(
  name='Operator',
  full_name='Operator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operatorID', full_name='Operator.operatorID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pilot', full_name='Operator.pilot', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_OPERATOR_PILOT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=351,
)


_FLIGHTDETAILS_UADETAILS = _descriptor.Descriptor(
  name='UADetails',
  full_name='FlightDetails.UADetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uinNo', full_name='FlightDetails.UADetails.uinNo', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=609,
)

_FLIGHTDETAILS_FLIGHTPURPOSE = _descriptor.Descriptor(
  name='FlightPurpose',
  full_name='FlightDetails.FlightPurpose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortDesc', full_name='FlightDetails.FlightPurpose.shortDesc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='FlightDetails.FlightPurpose.frequency', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=664,
)

_FLIGHTDETAILS_PAYLOADDETAILS = _descriptor.Descriptor(
  name='PayloadDetails',
  full_name='FlightDetails.PayloadDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payLoadWeight', full_name='FlightDetails.PayloadDetails.payLoadWeight', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payloadDetails', full_name='FlightDetails.PayloadDetails.payloadDetails', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=729,
)

_FLIGHTDETAILS_COORDINATE = _descriptor.Descriptor(
  name='Coordinate',
  full_name='FlightDetails.Coordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='FlightDetails.Coordinate.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='FlightDetails.Coordinate.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=780,
)

_FLIGHTDETAILS_FLIGHTPARAMETERS = _descriptor.Descriptor(
  name='FlightParameters',
  full_name='FlightDetails.FlightParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='FlightDetails.FlightParameters.coordinates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightStartTime', full_name='FlightDetails.FlightParameters.flightStartTime', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightEndTime', full_name='FlightDetails.FlightParameters.flightEndTime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequenciesUsed', full_name='FlightDetails.FlightParameters.frequenciesUsed', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=922,
)

_FLIGHTDETAILS = _descriptor.Descriptor(
  name='FlightDetails',
  full_name='FlightDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uaDetails', full_name='FlightDetails.uaDetails', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightPurpose', full_name='FlightDetails.flightPurpose', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payloadDetails', full_name='FlightDetails.payloadDetails', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flightParameters', full_name='FlightDetails.flightParameters', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FLIGHTDETAILS_UADETAILS, _FLIGHTDETAILS_FLIGHTPURPOSE, _FLIGHTDETAILS_PAYLOADDETAILS, _FLIGHTDETAILS_COORDINATE, _FLIGHTDETAILS_FLIGHTPARAMETERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=922,
)

_UAPERMISSION.fields_by_name['operator'].message_type = _OPERATOR
_UAPERMISSION.fields_by_name['flightDetails'].message_type = _FLIGHTDETAILS
_OPERATOR_PILOT.containing_type = _OPERATOR
_OPERATOR.fields_by_name['pilot'].message_type = _OPERATOR_PILOT
_FLIGHTDETAILS_UADETAILS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_FLIGHTPURPOSE.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_PAYLOADDETAILS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_COORDINATE.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS_FLIGHTPARAMETERS.fields_by_name['coordinates'].message_type = _FLIGHTDETAILS_COORDINATE
_FLIGHTDETAILS_FLIGHTPARAMETERS.containing_type = _FLIGHTDETAILS
_FLIGHTDETAILS.fields_by_name['uaDetails'].message_type = _FLIGHTDETAILS_UADETAILS
_FLIGHTDETAILS.fields_by_name['flightPurpose'].message_type = _FLIGHTDETAILS_FLIGHTPURPOSE
_FLIGHTDETAILS.fields_by_name['payloadDetails'].message_type = _FLIGHTDETAILS_PAYLOADDETAILS
_FLIGHTDETAILS.fields_by_name['flightParameters'].message_type = _FLIGHTDETAILS_FLIGHTPARAMETERS
DESCRIPTOR.message_types_by_name['UAPermission'] = _UAPERMISSION
DESCRIPTOR.message_types_by_name['Operator'] = _OPERATOR
DESCRIPTOR.message_types_by_name['FlightDetails'] = _FLIGHTDETAILS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UAPermission = _reflection.GeneratedProtocolMessageType('UAPermission', (_message.Message,), {
  'DESCRIPTOR' : _UAPERMISSION,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:UAPermission)
  })
_sym_db.RegisterMessage(UAPermission)

Operator = _reflection.GeneratedProtocolMessageType('Operator', (_message.Message,), {

  'Pilot' : _reflection.GeneratedProtocolMessageType('Pilot', (_message.Message,), {
    'DESCRIPTOR' : _OPERATOR_PILOT,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:Operator.Pilot)
    })
  ,
  'DESCRIPTOR' : _OPERATOR,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:Operator)
  })
_sym_db.RegisterMessage(Operator)
_sym_db.RegisterMessage(Operator.Pilot)

FlightDetails = _reflection.GeneratedProtocolMessageType('FlightDetails', (_message.Message,), {

  'UADetails' : _reflection.GeneratedProtocolMessageType('UADetails', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_UADETAILS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.UADetails)
    })
  ,

  'FlightPurpose' : _reflection.GeneratedProtocolMessageType('FlightPurpose', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_FLIGHTPURPOSE,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.FlightPurpose)
    })
  ,

  'PayloadDetails' : _reflection.GeneratedProtocolMessageType('PayloadDetails', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_PAYLOADDETAILS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.PayloadDetails)
    })
  ,

  'Coordinate' : _reflection.GeneratedProtocolMessageType('Coordinate', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_COORDINATE,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.Coordinate)
    })
  ,

  'FlightParameters' : _reflection.GeneratedProtocolMessageType('FlightParameters', (_message.Message,), {
    'DESCRIPTOR' : _FLIGHTDETAILS_FLIGHTPARAMETERS,
    '__module__' : 'rpas_india.PermissionArtefact_pb2'
    # @@protoc_insertion_point(class_scope:FlightDetails.FlightParameters)
    })
  ,
  'DESCRIPTOR' : _FLIGHTDETAILS,
  '__module__' : 'rpas_india.PermissionArtefact_pb2'
  # @@protoc_insertion_point(class_scope:FlightDetails)
  })
_sym_db.RegisterMessage(FlightDetails)
_sym_db.RegisterMessage(FlightDetails.UADetails)
_sym_db.RegisterMessage(FlightDetails.FlightPurpose)
_sym_db.RegisterMessage(FlightDetails.PayloadDetails)
_sym_db.RegisterMessage(FlightDetails.Coordinate)
_sym_db.RegisterMessage(FlightDetails.FlightParameters)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: solar-power-production/SolarPowerProductionStatic.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeaderStatic_pb2 as FeedHeaderStatic__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='solar-power-production/SolarPowerProductionStatic.proto',
  package='solar_production_static',
  syntax='proto3',
  serialized_options=b'\n\032io.pravah.solar.production',
  serialized_pb=b'\n7solar-power-production/SolarPowerProductionStatic.proto\x12\x17solar_production_static\x1a\x16\x46\x65\x65\x64HeaderStatic.proto\"h\n\x0b\x46\x65\x65\x64Message\x12!\n\x06header\x18\x01 \x01(\x0b\x32\x11.FeedHeaderStatic\x12\x36\n\x08stations\x18\x02 \x03(\x0b\x32$.solar_production_static.FeedStation\"\x99\x02\n\x0b\x46\x65\x65\x64Station\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\rspecification\x18\x03 \x01(\x0b\x32&.solar_production_static.Specification\x12\x43\n\x10installationSpec\x18\x04 \x01(\x0b\x32).solar_production_static.InstallationSpec\x12\x37\n\x0cinverterList\x18\x05 \x03(\x0b\x32!.solar_production_static.Inverter\x12\x33\n\x08location\x18\x06 \x01(\x0b\x32!.solar_production_static.Location\"\xcf\x01\n\x08Inverter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12=\n\rspecification\x18\x03 \x01(\x0b\x32&.solar_production_static.Specification\x12\x35\n\tpanelInfo\x18\x04 \x01(\x0b\x32\".solar_production_static.PanelInfo\x12\x33\n\x08location\x18\x05 \x01(\x0b\x32!.solar_production_static.Location\"V\n\tPanelInfo\x12\x12\n\npanelCount\x18\x01 \x01(\r\x12\r\n\x05model\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x02\",\n\x10InstallationSpec\x12\x18\n\x10installationType\x18\x01 \x01(\t\"K\n\rSpecification\x12\x15\n\rpowerCapacity\x18\x01 \x01(\x01\x12\r\n\x05model\x18\x02 \x01(\t\x12\x14\n\x0cmanufacturer\x18\x03 \x01(\t\"@\n\x08Location\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x1c\n\x1aio.pravah.solar.productionb\x06proto3'
  ,
  dependencies=[FeedHeaderStatic__pb2.DESCRIPTOR,])




_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='solar_production_static.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='solar_production_static.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stations', full_name='solar_production_static.FeedMessage.stations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=212,
)


_FEEDSTATION = _descriptor.Descriptor(
  name='FeedStation',
  full_name='solar_production_static.FeedStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production_static.FeedStation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='solar_production_static.FeedStation.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specification', full_name='solar_production_static.FeedStation.specification', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='installationSpec', full_name='solar_production_static.FeedStation.installationSpec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverterList', full_name='solar_production_static.FeedStation.inverterList', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='solar_production_static.FeedStation.location', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=496,
)


_INVERTER = _descriptor.Descriptor(
  name='Inverter',
  full_name='solar_production_static.Inverter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='solar_production_static.Inverter.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='solar_production_static.Inverter.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specification', full_name='solar_production_static.Inverter.specification', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='panelInfo', full_name='solar_production_static.Inverter.panelInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='solar_production_static.Inverter.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=706,
)


_PANELINFO = _descriptor.Descriptor(
  name='PanelInfo',
  full_name='solar_production_static.PanelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='panelCount', full_name='solar_production_static.PanelInfo.panelCount', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='solar_production_static.PanelInfo.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer', full_name='solar_production_static.PanelInfo.manufacturer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='solar_production_static.PanelInfo.capacity', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=708,
  serialized_end=794,
)


_INSTALLATIONSPEC = _descriptor.Descriptor(
  name='InstallationSpec',
  full_name='solar_production_static.InstallationSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='installationType', full_name='solar_production_static.InstallationSpec.installationType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=840,
)


_SPECIFICATION = _descriptor.Descriptor(
  name='Specification',
  full_name='solar_production_static.Specification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='powerCapacity', full_name='solar_production_static.Specification.powerCapacity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='solar_production_static.Specification.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manufacturer', full_name='solar_production_static.Specification.manufacturer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=917,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='solar_production_static.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='solar_production_static.Location.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='solar_production_static.Location.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='solar_production_static.Location.address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=919,
  serialized_end=983,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeaderStatic__pb2._FEEDHEADERSTATIC
_FEEDMESSAGE.fields_by_name['stations'].message_type = _FEEDSTATION
_FEEDSTATION.fields_by_name['specification'].message_type = _SPECIFICATION
_FEEDSTATION.fields_by_name['installationSpec'].message_type = _INSTALLATIONSPEC
_FEEDSTATION.fields_by_name['inverterList'].message_type = _INVERTER
_FEEDSTATION.fields_by_name['location'].message_type = _LOCATION
_INVERTER.fields_by_name['specification'].message_type = _SPECIFICATION
_INVERTER.fields_by_name['panelInfo'].message_type = _PANELINFO
_INVERTER.fields_by_name['location'].message_type = _LOCATION
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedStation'] = _FEEDSTATION
DESCRIPTOR.message_types_by_name['Inverter'] = _INVERTER
DESCRIPTOR.message_types_by_name['PanelInfo'] = _PANELINFO
DESCRIPTOR.message_types_by_name['InstallationSpec'] = _INSTALLATIONSPEC
DESCRIPTOR.message_types_by_name['Specification'] = _SPECIFICATION
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedStation = _reflection.GeneratedProtocolMessageType('FeedStation', (_message.Message,), {
  'DESCRIPTOR' : _FEEDSTATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.FeedStation)
  })
_sym_db.RegisterMessage(FeedStation)

Inverter = _reflection.GeneratedProtocolMessageType('Inverter', (_message.Message,), {
  'DESCRIPTOR' : _INVERTER,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Inverter)
  })
_sym_db.RegisterMessage(Inverter)

PanelInfo = _reflection.GeneratedProtocolMessageType('PanelInfo', (_message.Message,), {
  'DESCRIPTOR' : _PANELINFO,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.PanelInfo)
  })
_sym_db.RegisterMessage(PanelInfo)

InstallationSpec = _reflection.GeneratedProtocolMessageType('InstallationSpec', (_message.Message,), {
  'DESCRIPTOR' : _INSTALLATIONSPEC,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.InstallationSpec)
  })
_sym_db.RegisterMessage(InstallationSpec)

Specification = _reflection.GeneratedProtocolMessageType('Specification', (_message.Message,), {
  'DESCRIPTOR' : _SPECIFICATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Specification)
  })
_sym_db.RegisterMessage(Specification)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'solar_power_production.SolarPowerProductionStatic_pb2'
  # @@protoc_insertion_point(class_scope:solar_production_static.Location)
  })
_sym_db.RegisterMessage(Location)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gtfs/PublicBus.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeader_pb2 as FeedHeader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gtfs/PublicBus.proto',
  package='transit_realtime',
  syntax='proto2',
  serialized_options=b'\n\021io.pravah.transit',
  serialized_pb=b'\n\x14gtfs/PublicBus.proto\x12\x10transit_realtime\x1a\x10\x46\x65\x65\x64Header.proto\"`\n\x0b\x46\x65\x65\x64Message\x12\x1b\n\x06header\x18\x01 \x02(\x0b\x32\x0b.FeedHeader\x12,\n\x06\x65ntity\x18\x02 \x03(\x0b\x32\x1c.transit_realtime.FeedEntity*\x06\x08\xe8\x07\x10\xd0\x0f\"\xca\x01\n\nFeedEntity\x12\n\n\x02id\x18\x01 \x02(\t\x12\x19\n\nis_deleted\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x31\n\x0btrip_update\x18\x03 \x01(\x0b\x32\x1c.transit_realtime.TripUpdate\x12\x32\n\x07vehicle\x18\x04 \x01(\x0b\x32!.transit_realtime.VehiclePosition\x12&\n\x05\x61lert\x18\x05 \x01(\x0b\x32\x17.transit_realtime.Alert*\x06\x08\xe8\x07\x10\xd0\x0f\"\xab\x05\n\nTripUpdate\x12.\n\x04trip\x18\x01 \x02(\x0b\x32 .transit_realtime.TripDescriptor\x12\x34\n\x07vehicle\x18\x03 \x01(\x0b\x32#.transit_realtime.VehicleDescriptor\x12\x45\n\x10stop_time_update\x18\x02 \x03(\x0b\x32+.transit_realtime.TripUpdate.StopTimeUpdate\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12\r\n\x05\x64\x65lay\x18\x05 \x01(\x05\x1aI\n\rStopTimeEvent\x12\r\n\x05\x64\x65lay\x18\x01 \x01(\x05\x12\x0c\n\x04time\x18\x02 \x01(\x03\x12\x13\n\x0buncertainty\x18\x03 \x01(\x05*\x06\x08\xe8\x07\x10\xd0\x0f\x1a\xfa\x02\n\x0eStopTimeUpdate\x12\x15\n\rstop_sequence\x18\x01 \x01(\r\x12\x0f\n\x07stop_id\x18\x04 \x01(\t\x12;\n\x07\x61rrival\x18\x02 \x01(\x0b\x32*.transit_realtime.TripUpdate.StopTimeEvent\x12=\n\tdeparture\x18\x03 \x01(\x0b\x32*.transit_realtime.TripUpdate.StopTimeEvent\x12j\n\x15schedule_relationship\x18\x05 \x01(\x0e\x32@.transit_realtime.TripUpdate.StopTimeUpdate.ScheduleRelationship:\tSCHEDULED\"P\n\x14ScheduleRelationship\x12\r\n\tSCHEDULED\x10\x00\x12\x0b\n\x07SKIPPED\x10\x01\x12\x0b\n\x07NO_DATA\x10\x02\x12\x0f\n\x0bUNSCHEDULED\x10\x03*\x06\x08\xe8\x07\x10\xd0\x0f*\x06\x08\xe8\x07\x10\xd0\x0f\"\xe0\x06\n\x0fVehiclePosition\x12.\n\x04trip\x18\x01 \x01(\x0b\x32 .transit_realtime.TripDescriptor\x12\x34\n\x07vehicle\x18\x08 \x01(\x0b\x32#.transit_realtime.VehicleDescriptor\x12,\n\x08position\x18\x02 \x01(\x0b\x32\x1a.transit_realtime.Position\x12\x1d\n\x15\x63urrent_stop_sequence\x18\x03 \x01(\r\x12\x0f\n\x07stop_id\x18\x07 \x01(\t\x12Z\n\x0e\x63urrent_status\x18\x04 \x01(\x0e\x32\x33.transit_realtime.VehiclePosition.VehicleStopStatus:\rIN_TRANSIT_TO\x12\x11\n\ttimestamp\x18\x05 \x01(\x04\x12K\n\x10\x63ongestion_level\x18\x06 \x01(\x0e\x32\x31.transit_realtime.VehiclePosition.CongestionLevel\x12K\n\x10occupancy_status\x18\t \x01(\x0e\x32\x31.transit_realtime.VehiclePosition.OccupancyStatus\"G\n\x11VehicleStopStatus\x12\x0f\n\x0bINCOMING_AT\x10\x00\x12\x0e\n\nSTOPPED_AT\x10\x01\x12\x11\n\rIN_TRANSIT_TO\x10\x02\"}\n\x0f\x43ongestionLevel\x12\x1c\n\x18UNKNOWN_CONGESTION_LEVEL\x10\x00\x12\x14\n\x10RUNNING_SMOOTHLY\x10\x01\x12\x0f\n\x0bSTOP_AND_GO\x10\x02\x12\x0e\n\nCONGESTION\x10\x03\x12\x15\n\x11SEVERE_CONGESTION\x10\x04\"\xaf\x01\n\x0fOccupancyStatus\x12\t\n\x05\x45MPTY\x10\x00\x12\x18\n\x14MANY_SEATS_AVAILABLE\x10\x01\x12\x17\n\x13\x46\x45W_SEATS_AVAILABLE\x10\x02\x12\x16\n\x12STANDING_ROOM_ONLY\x10\x03\x12\x1e\n\x1a\x43RUSHED_STANDING_ROOM_ONLY\x10\x04\x12\x08\n\x04\x46ULL\x10\x05\x12\x1c\n\x18NOT_ACCEPTING_PASSENGERS\x10\x06*\x06\x08\xe8\x07\x10\xd0\x0f\"\xf8\x08\n\x05\x41lert\x12\x32\n\ractive_period\x18\x01 \x03(\x0b\x32\x1b.transit_realtime.TimeRange\x12\x39\n\x0finformed_entity\x18\x05 \x03(\x0b\x32 .transit_realtime.EntitySelector\x12;\n\x05\x63\x61use\x18\x06 \x01(\x0e\x32\x1d.transit_realtime.Alert.Cause:\rUNKNOWN_CAUSE\x12>\n\x06\x65\x66\x66\x65\x63t\x18\x07 \x01(\x0e\x32\x1e.transit_realtime.Alert.Effect:\x0eUNKNOWN_EFFECT\x12/\n\x03url\x18\x08 \x01(\x0b\x32\".transit_realtime.TranslatedString\x12\x37\n\x0bheader_text\x18\n \x01(\x0b\x32\".transit_realtime.TranslatedString\x12<\n\x10\x64\x65scription_text\x18\x0b \x01(\x0b\x32\".transit_realtime.TranslatedString\x12;\n\x0ftts_header_text\x18\x0c \x01(\x0b\x32\".transit_realtime.TranslatedString\x12@\n\x14tts_description_text\x18\r \x01(\x0b\x32\".transit_realtime.TranslatedString\x12O\n\x0eseverity_level\x18\x0e \x01(\x0e\x32%.transit_realtime.Alert.SeverityLevel:\x10UNKNOWN_SEVERITY\"\xd8\x01\n\x05\x43\x61use\x12\x11\n\rUNKNOWN_CAUSE\x10\x01\x12\x0f\n\x0bOTHER_CAUSE\x10\x02\x12\x15\n\x11TECHNICAL_PROBLEM\x10\x03\x12\n\n\x06STRIKE\x10\x04\x12\x11\n\rDEMONSTRATION\x10\x05\x12\x0c\n\x08\x41\x43\x43IDENT\x10\x06\x12\x0b\n\x07HOLIDAY\x10\x07\x12\x0b\n\x07WEATHER\x10\x08\x12\x0f\n\x0bMAINTENANCE\x10\t\x12\x10\n\x0c\x43ONSTRUCTION\x10\n\x12\x13\n\x0fPOLICE_ACTIVITY\x10\x0b\x12\x15\n\x11MEDICAL_EMERGENCY\x10\x0c\"\xdd\x01\n\x06\x45\x66\x66\x65\x63t\x12\x0e\n\nNO_SERVICE\x10\x01\x12\x13\n\x0fREDUCED_SERVICE\x10\x02\x12\x16\n\x12SIGNIFICANT_DELAYS\x10\x03\x12\n\n\x06\x44\x45TOUR\x10\x04\x12\x16\n\x12\x41\x44\x44ITIONAL_SERVICE\x10\x05\x12\x14\n\x10MODIFIED_SERVICE\x10\x06\x12\x10\n\x0cOTHER_EFFECT\x10\x07\x12\x12\n\x0eUNKNOWN_EFFECT\x10\x08\x12\x0e\n\nSTOP_MOVED\x10\t\x12\r\n\tNO_EFFECT\x10\n\x12\x17\n\x13\x41\x43\x43\x45SSIBILITY_ISSUE\x10\x0b\"H\n\rSeverityLevel\x12\x14\n\x10UNKNOWN_SEVERITY\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\n\n\x06SEVERE\x10\x04*\x06\x08\xe8\x07\x10\xd0\x0f\"/\n\tTimeRange\x12\r\n\x05start\x18\x01 \x01(\x04\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x04*\x06\x08\xe8\x07\x10\xd0\x0f\"i\n\x08Position\x12\x10\n\x08latitude\x18\x01 \x02(\x02\x12\x11\n\tlongitude\x18\x02 \x02(\x02\x12\x0f\n\x07\x62\x65\x61ring\x18\x03 \x01(\x02\x12\x10\n\x08odometer\x18\x04 \x01(\x01\x12\r\n\x05speed\x18\x05 \x01(\x02*\x06\x08\xe8\x07\x10\xd0\x0f\"\xb5\x02\n\x0eTripDescriptor\x12\x0f\n\x07trip_id\x18\x01 \x01(\t\x12\x10\n\x08route_id\x18\x05 \x01(\t\x12\x14\n\x0c\x64irection_id\x18\x06 \x01(\r\x12\x12\n\nstart_time\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\t\x12T\n\x15schedule_relationship\x18\x04 \x01(\x0e\x32\x35.transit_realtime.TripDescriptor.ScheduleRelationship\"d\n\x14ScheduleRelationship\x12\r\n\tSCHEDULED\x10\x00\x12\t\n\x05\x41\x44\x44\x45\x44\x10\x01\x12\x0f\n\x0bUNSCHEDULED\x10\x02\x12\x0c\n\x08\x43\x41NCELED\x10\x03\x12\x13\n\x0bREPLACEMENT\x10\x05\x1a\x02\x08\x01*\x06\x08\xe8\x07\x10\xd0\x0f\"M\n\x11VehicleDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x15\n\rlicense_plate\x18\x03 \x01(\t*\x06\x08\xe8\x07\x10\xd0\x0f\"\xa8\x01\n\x0e\x45ntitySelector\x12\x11\n\tagency_id\x18\x01 \x01(\t\x12\x10\n\x08route_id\x18\x02 \x01(\t\x12\x12\n\nroute_type\x18\x03 \x01(\x05\x12.\n\x04trip\x18\x04 \x01(\x0b\x32 .transit_realtime.TripDescriptor\x12\x0f\n\x07stop_id\x18\x05 \x01(\t\x12\x14\n\x0c\x64irection_id\x18\x06 \x01(\r*\x06\x08\xe8\x07\x10\xd0\x0f\"\x96\x01\n\x10TranslatedString\x12\x43\n\x0btranslation\x18\x01 \x03(\x0b\x32..transit_realtime.TranslatedString.Translation\x1a\x35\n\x0bTranslation\x12\x0c\n\x04text\x18\x01 \x02(\t\x12\x10\n\x08language\x18\x02 \x01(\t*\x06\x08\xe8\x07\x10\xd0\x0f*\x06\x08\xe8\x07\x10\xd0\x0f\x42\x13\n\x11io.pravah.transit'
  ,
  dependencies=[FeedHeader__pb2.DESCRIPTOR,])



_TRIPUPDATE_STOPTIMEUPDATE_SCHEDULERELATIONSHIP = _descriptor.EnumDescriptor(
  name='ScheduleRelationship',
  full_name='transit_realtime.TripUpdate.StopTimeUpdate.ScheduleRelationship',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SKIPPED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_DATA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSCHEDULED', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=951,
  serialized_end=1031,
)
_sym_db.RegisterEnumDescriptor(_TRIPUPDATE_STOPTIMEUPDATE_SCHEDULERELATIONSHIP)

_VEHICLEPOSITION_VEHICLESTOPSTATUS = _descriptor.EnumDescriptor(
  name='VehicleStopStatus',
  full_name='transit_realtime.VehiclePosition.VehicleStopStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INCOMING_AT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED_AT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IN_TRANSIT_TO', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1530,
  serialized_end=1601,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEPOSITION_VEHICLESTOPSTATUS)

_VEHICLEPOSITION_CONGESTIONLEVEL = _descriptor.EnumDescriptor(
  name='CongestionLevel',
  full_name='transit_realtime.VehiclePosition.CongestionLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CONGESTION_LEVEL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING_SMOOTHLY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_AND_GO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONGESTION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE_CONGESTION', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1603,
  serialized_end=1728,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEPOSITION_CONGESTIONLEVEL)

_VEHICLEPOSITION_OCCUPANCYSTATUS = _descriptor.EnumDescriptor(
  name='OccupancyStatus',
  full_name='transit_realtime.VehiclePosition.OccupancyStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMPTY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MANY_SEATS_AVAILABLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEW_SEATS_AVAILABLE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STANDING_ROOM_ONLY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRUSHED_STANDING_ROOM_ONLY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_ACCEPTING_PASSENGERS', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1731,
  serialized_end=1906,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEPOSITION_OCCUPANCYSTATUS)

_ALERT_CAUSE = _descriptor.EnumDescriptor(
  name='Cause',
  full_name='transit_realtime.Alert.Cause',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CAUSE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER_CAUSE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TECHNICAL_PROBLEM', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRIKE', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEMONSTRATION', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCIDENT', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOLIDAY', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WEATHER', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAINTENANCE', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONSTRUCTION', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POLICE_ACTIVITY', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_EMERGENCY', index=11, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2539,
  serialized_end=2755,
)
_sym_db.RegisterEnumDescriptor(_ALERT_CAUSE)

_ALERT_EFFECT = _descriptor.EnumDescriptor(
  name='Effect',
  full_name='transit_realtime.Alert.Effect',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_SERVICE', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REDUCED_SERVICE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGNIFICANT_DELAYS', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DETOUR', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDITIONAL_SERVICE', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MODIFIED_SERVICE', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OTHER_EFFECT', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_EFFECT', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP_MOVED', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_EFFECT', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCESSIBILITY_ISSUE', index=10, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2758,
  serialized_end=2979,
)
_sym_db.RegisterEnumDescriptor(_ALERT_EFFECT)

_ALERT_SEVERITYLEVEL = _descriptor.EnumDescriptor(
  name='SeverityLevel',
  full_name='transit_realtime.Alert.SeverityLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_SEVERITY', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEVERE', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2981,
  serialized_end=3053,
)
_sym_db.RegisterEnumDescriptor(_ALERT_SEVERITYLEVEL)

_TRIPDESCRIPTOR_SCHEDULERELATIONSHIP = _descriptor.EnumDescriptor(
  name='ScheduleRelationship',
  full_name='transit_realtime.TripDescriptor.ScheduleRelationship',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSCHEDULED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPLACEMENT', index=4, number=5,
      serialized_options=b'\010\001',
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3421,
  serialized_end=3521,
)
_sym_db.RegisterEnumDescriptor(_TRIPDESCRIPTOR_SCHEDULERELATIONSHIP)


_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='transit_realtime.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='transit_realtime.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='transit_realtime.FeedMessage.entity', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=156,
)


_FEEDENTITY = _descriptor.Descriptor(
  name='FeedEntity',
  full_name='transit_realtime.FeedEntity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='transit_realtime.FeedEntity.id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_deleted', full_name='transit_realtime.FeedEntity.is_deleted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trip_update', full_name='transit_realtime.FeedEntity.trip_update', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicle', full_name='transit_realtime.FeedEntity.vehicle', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alert', full_name='transit_realtime.FeedEntity.alert', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=361,
)


_TRIPUPDATE_STOPTIMEEVENT = _descriptor.Descriptor(
  name='StopTimeEvent',
  full_name='transit_realtime.TripUpdate.StopTimeEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delay', full_name='transit_realtime.TripUpdate.StopTimeEvent.delay', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='transit_realtime.TripUpdate.StopTimeEvent.time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uncertainty', full_name='transit_realtime.TripUpdate.StopTimeEvent.uncertainty', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=658,
)

_TRIPUPDATE_STOPTIMEUPDATE = _descriptor.Descriptor(
  name='StopTimeUpdate',
  full_name='transit_realtime.TripUpdate.StopTimeUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_sequence', full_name='transit_realtime.TripUpdate.StopTimeUpdate.stop_sequence', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_id', full_name='transit_realtime.TripUpdate.StopTimeUpdate.stop_id', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrival', full_name='transit_realtime.TripUpdate.StopTimeUpdate.arrival', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='departure', full_name='transit_realtime.TripUpdate.StopTimeUpdate.departure', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule_relationship', full_name='transit_realtime.TripUpdate.StopTimeUpdate.schedule_relationship', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRIPUPDATE_STOPTIMEUPDATE_SCHEDULERELATIONSHIP,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=1039,
)

_TRIPUPDATE = _descriptor.Descriptor(
  name='TripUpdate',
  full_name='transit_realtime.TripUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trip', full_name='transit_realtime.TripUpdate.trip', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicle', full_name='transit_realtime.TripUpdate.vehicle', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_time_update', full_name='transit_realtime.TripUpdate.stop_time_update', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='transit_realtime.TripUpdate.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delay', full_name='transit_realtime.TripUpdate.delay', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRIPUPDATE_STOPTIMEEVENT, _TRIPUPDATE_STOPTIMEUPDATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=364,
  serialized_end=1047,
)


_VEHICLEPOSITION = _descriptor.Descriptor(
  name='VehiclePosition',
  full_name='transit_realtime.VehiclePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trip', full_name='transit_realtime.VehiclePosition.trip', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vehicle', full_name='transit_realtime.VehiclePosition.vehicle', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='transit_realtime.VehiclePosition.position', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_stop_sequence', full_name='transit_realtime.VehiclePosition.current_stop_sequence', index=3,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_id', full_name='transit_realtime.VehiclePosition.stop_id', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='current_status', full_name='transit_realtime.VehiclePosition.current_status', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='transit_realtime.VehiclePosition.timestamp', index=6,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='congestion_level', full_name='transit_realtime.VehiclePosition.congestion_level', index=7,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occupancy_status', full_name='transit_realtime.VehiclePosition.occupancy_status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLEPOSITION_VEHICLESTOPSTATUS,
    _VEHICLEPOSITION_CONGESTIONLEVEL,
    _VEHICLEPOSITION_OCCUPANCYSTATUS,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=1050,
  serialized_end=1914,
)


_ALERT = _descriptor.Descriptor(
  name='Alert',
  full_name='transit_realtime.Alert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_period', full_name='transit_realtime.Alert.active_period', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='informed_entity', full_name='transit_realtime.Alert.informed_entity', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cause', full_name='transit_realtime.Alert.cause', index=2,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='effect', full_name='transit_realtime.Alert.effect', index=3,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='transit_realtime.Alert.url', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_text', full_name='transit_realtime.Alert.header_text', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description_text', full_name='transit_realtime.Alert.description_text', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tts_header_text', full_name='transit_realtime.Alert.tts_header_text', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tts_description_text', full_name='transit_realtime.Alert.tts_description_text', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity_level', full_name='transit_realtime.Alert.severity_level', index=9,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALERT_CAUSE,
    _ALERT_EFFECT,
    _ALERT_SEVERITYLEVEL,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=1917,
  serialized_end=3061,
)


_TIMERANGE = _descriptor.Descriptor(
  name='TimeRange',
  full_name='transit_realtime.TimeRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='transit_realtime.TimeRange.start', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='transit_realtime.TimeRange.end', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3063,
  serialized_end=3110,
)


_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='transit_realtime.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='transit_realtime.Position.latitude', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='transit_realtime.Position.longitude', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bearing', full_name='transit_realtime.Position.bearing', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='odometer', full_name='transit_realtime.Position.odometer', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='transit_realtime.Position.speed', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3112,
  serialized_end=3217,
)


_TRIPDESCRIPTOR = _descriptor.Descriptor(
  name='TripDescriptor',
  full_name='transit_realtime.TripDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trip_id', full_name='transit_realtime.TripDescriptor.trip_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_id', full_name='transit_realtime.TripDescriptor.route_id', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction_id', full_name='transit_realtime.TripDescriptor.direction_id', index=2,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='transit_realtime.TripDescriptor.start_time', index=3,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='transit_realtime.TripDescriptor.start_date', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schedule_relationship', full_name='transit_realtime.TripDescriptor.schedule_relationship', index=5,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRIPDESCRIPTOR_SCHEDULERELATIONSHIP,
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3220,
  serialized_end=3529,
)


_VEHICLEDESCRIPTOR = _descriptor.Descriptor(
  name='VehicleDescriptor',
  full_name='transit_realtime.VehicleDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='transit_realtime.VehicleDescriptor.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='transit_realtime.VehicleDescriptor.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='license_plate', full_name='transit_realtime.VehicleDescriptor.license_plate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3531,
  serialized_end=3608,
)


_ENTITYSELECTOR = _descriptor.Descriptor(
  name='EntitySelector',
  full_name='transit_realtime.EntitySelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='agency_id', full_name='transit_realtime.EntitySelector.agency_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_id', full_name='transit_realtime.EntitySelector.route_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='route_type', full_name='transit_realtime.EntitySelector.route_type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trip', full_name='transit_realtime.EntitySelector.trip', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop_id', full_name='transit_realtime.EntitySelector.stop_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction_id', full_name='transit_realtime.EntitySelector.direction_id', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3611,
  serialized_end=3779,
)


_TRANSLATEDSTRING_TRANSLATION = _descriptor.Descriptor(
  name='Translation',
  full_name='transit_realtime.TranslatedString.Translation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='transit_realtime.TranslatedString.Translation.text', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='transit_realtime.TranslatedString.Translation.language', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3871,
  serialized_end=3924,
)

_TRANSLATEDSTRING = _descriptor.Descriptor(
  name='TranslatedString',
  full_name='transit_realtime.TranslatedString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='translation', full_name='transit_realtime.TranslatedString.translation', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRANSLATEDSTRING_TRANSLATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 2000), ],
  oneofs=[
  ],
  serialized_start=3782,
  serialized_end=3932,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeader__pb2._FEEDHEADER
_FEEDMESSAGE.fields_by_name['entity'].message_type = _FEEDENTITY
_FEEDENTITY.fields_by_name['trip_update'].message_type = _TRIPUPDATE
_FEEDENTITY.fields_by_name['vehicle'].message_type = _VEHICLEPOSITION
_FEEDENTITY.fields_by_name['alert'].message_type = _ALERT
_TRIPUPDATE_STOPTIMEEVENT.containing_type = _TRIPUPDATE
_TRIPUPDATE_STOPTIMEUPDATE.fields_by_name['arrival'].message_type = _TRIPUPDATE_STOPTIMEEVENT
_TRIPUPDATE_STOPTIMEUPDATE.fields_by_name['departure'].message_type = _TRIPUPDATE_STOPTIMEEVENT
_TRIPUPDATE_STOPTIMEUPDATE.fields_by_name['schedule_relationship'].enum_type = _TRIPUPDATE_STOPTIMEUPDATE_SCHEDULERELATIONSHIP
_TRIPUPDATE_STOPTIMEUPDATE.containing_type = _TRIPUPDATE
_TRIPUPDATE_STOPTIMEUPDATE_SCHEDULERELATIONSHIP.containing_type = _TRIPUPDATE_STOPTIMEUPDATE
_TRIPUPDATE.fields_by_name['trip'].message_type = _TRIPDESCRIPTOR
_TRIPUPDATE.fields_by_name['vehicle'].message_type = _VEHICLEDESCRIPTOR
_TRIPUPDATE.fields_by_name['stop_time_update'].message_type = _TRIPUPDATE_STOPTIMEUPDATE
_VEHICLEPOSITION.fields_by_name['trip'].message_type = _TRIPDESCRIPTOR
_VEHICLEPOSITION.fields_by_name['vehicle'].message_type = _VEHICLEDESCRIPTOR
_VEHICLEPOSITION.fields_by_name['position'].message_type = _POSITION
_VEHICLEPOSITION.fields_by_name['current_status'].enum_type = _VEHICLEPOSITION_VEHICLESTOPSTATUS
_VEHICLEPOSITION.fields_by_name['congestion_level'].enum_type = _VEHICLEPOSITION_CONGESTIONLEVEL
_VEHICLEPOSITION.fields_by_name['occupancy_status'].enum_type = _VEHICLEPOSITION_OCCUPANCYSTATUS
_VEHICLEPOSITION_VEHICLESTOPSTATUS.containing_type = _VEHICLEPOSITION
_VEHICLEPOSITION_CONGESTIONLEVEL.containing_type = _VEHICLEPOSITION
_VEHICLEPOSITION_OCCUPANCYSTATUS.containing_type = _VEHICLEPOSITION
_ALERT.fields_by_name['active_period'].message_type = _TIMERANGE
_ALERT.fields_by_name['informed_entity'].message_type = _ENTITYSELECTOR
_ALERT.fields_by_name['cause'].enum_type = _ALERT_CAUSE
_ALERT.fields_by_name['effect'].enum_type = _ALERT_EFFECT
_ALERT.fields_by_name['url'].message_type = _TRANSLATEDSTRING
_ALERT.fields_by_name['header_text'].message_type = _TRANSLATEDSTRING
_ALERT.fields_by_name['description_text'].message_type = _TRANSLATEDSTRING
_ALERT.fields_by_name['tts_header_text'].message_type = _TRANSLATEDSTRING
_ALERT.fields_by_name['tts_description_text'].message_type = _TRANSLATEDSTRING
_ALERT.fields_by_name['severity_level'].enum_type = _ALERT_SEVERITYLEVEL
_ALERT_CAUSE.containing_type = _ALERT
_ALERT_EFFECT.containing_type = _ALERT
_ALERT_SEVERITYLEVEL.containing_type = _ALERT
_TRIPDESCRIPTOR.fields_by_name['schedule_relationship'].enum_type = _TRIPDESCRIPTOR_SCHEDULERELATIONSHIP
_TRIPDESCRIPTOR_SCHEDULERELATIONSHIP.containing_type = _TRIPDESCRIPTOR
_ENTITYSELECTOR.fields_by_name['trip'].message_type = _TRIPDESCRIPTOR
_TRANSLATEDSTRING_TRANSLATION.containing_type = _TRANSLATEDSTRING
_TRANSLATEDSTRING.fields_by_name['translation'].message_type = _TRANSLATEDSTRING_TRANSLATION
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedEntity'] = _FEEDENTITY
DESCRIPTOR.message_types_by_name['TripUpdate'] = _TRIPUPDATE
DESCRIPTOR.message_types_by_name['VehiclePosition'] = _VEHICLEPOSITION
DESCRIPTOR.message_types_by_name['Alert'] = _ALERT
DESCRIPTOR.message_types_by_name['TimeRange'] = _TIMERANGE
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['TripDescriptor'] = _TRIPDESCRIPTOR
DESCRIPTOR.message_types_by_name['VehicleDescriptor'] = _VEHICLEDESCRIPTOR
DESCRIPTOR.message_types_by_name['EntitySelector'] = _ENTITYSELECTOR
DESCRIPTOR.message_types_by_name['TranslatedString'] = _TRANSLATEDSTRING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedEntity = _reflection.GeneratedProtocolMessageType('FeedEntity', (_message.Message,), {
  'DESCRIPTOR' : _FEEDENTITY,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.FeedEntity)
  })
_sym_db.RegisterMessage(FeedEntity)

TripUpdate = _reflection.GeneratedProtocolMessageType('TripUpdate', (_message.Message,), {

  'StopTimeEvent' : _reflection.GeneratedProtocolMessageType('StopTimeEvent', (_message.Message,), {
    'DESCRIPTOR' : _TRIPUPDATE_STOPTIMEEVENT,
    '__module__' : 'gtfs.PublicBus_pb2'
    # @@protoc_insertion_point(class_scope:transit_realtime.TripUpdate.StopTimeEvent)
    })
  ,

  'StopTimeUpdate' : _reflection.GeneratedProtocolMessageType('StopTimeUpdate', (_message.Message,), {
    'DESCRIPTOR' : _TRIPUPDATE_STOPTIMEUPDATE,
    '__module__' : 'gtfs.PublicBus_pb2'
    # @@protoc_insertion_point(class_scope:transit_realtime.TripUpdate.StopTimeUpdate)
    })
  ,
  'DESCRIPTOR' : _TRIPUPDATE,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.TripUpdate)
  })
_sym_db.RegisterMessage(TripUpdate)
_sym_db.RegisterMessage(TripUpdate.StopTimeEvent)
_sym_db.RegisterMessage(TripUpdate.StopTimeUpdate)

VehiclePosition = _reflection.GeneratedProtocolMessageType('VehiclePosition', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEPOSITION,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.VehiclePosition)
  })
_sym_db.RegisterMessage(VehiclePosition)

Alert = _reflection.GeneratedProtocolMessageType('Alert', (_message.Message,), {
  'DESCRIPTOR' : _ALERT,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.Alert)
  })
_sym_db.RegisterMessage(Alert)

TimeRange = _reflection.GeneratedProtocolMessageType('TimeRange', (_message.Message,), {
  'DESCRIPTOR' : _TIMERANGE,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.TimeRange)
  })
_sym_db.RegisterMessage(TimeRange)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
  'DESCRIPTOR' : _POSITION,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.Position)
  })
_sym_db.RegisterMessage(Position)

TripDescriptor = _reflection.GeneratedProtocolMessageType('TripDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _TRIPDESCRIPTOR,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.TripDescriptor)
  })
_sym_db.RegisterMessage(TripDescriptor)

VehicleDescriptor = _reflection.GeneratedProtocolMessageType('VehicleDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDESCRIPTOR,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.VehicleDescriptor)
  })
_sym_db.RegisterMessage(VehicleDescriptor)

EntitySelector = _reflection.GeneratedProtocolMessageType('EntitySelector', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYSELECTOR,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.EntitySelector)
  })
_sym_db.RegisterMessage(EntitySelector)

TranslatedString = _reflection.GeneratedProtocolMessageType('TranslatedString', (_message.Message,), {

  'Translation' : _reflection.GeneratedProtocolMessageType('Translation', (_message.Message,), {
    'DESCRIPTOR' : _TRANSLATEDSTRING_TRANSLATION,
    '__module__' : 'gtfs.PublicBus_pb2'
    # @@protoc_insertion_point(class_scope:transit_realtime.TranslatedString.Translation)
    })
  ,
  'DESCRIPTOR' : _TRANSLATEDSTRING,
  '__module__' : 'gtfs.PublicBus_pb2'
  # @@protoc_insertion_point(class_scope:transit_realtime.TranslatedString)
  })
_sym_db.RegisterMessage(TranslatedString)
_sym_db.RegisterMessage(TranslatedString.Translation)


DESCRIPTOR._options = None
_TRIPDESCRIPTOR_SCHEDULERELATIONSHIP.values_by_name["REPLACEMENT"]._options = None
# @@protoc_insertion_point(module_scope)
